==> qtjambi-debuginfo-macos-5.15.17.jar: sources/QtJambiGui/QPlatformSurfaceEvent_shell.cpp <==
#include "QPlatformSurfaceEvent_shell.h"
#include <QtJambi/Cast>

void deleter_QPlatformSurfaceEvent(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QPlatformSurfaceEvent")
    QPlatformSurfaceEvent *_ptr = reinterpret_cast<QPlatformSurfaceEvent *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

QtJambiShell* QPlatformSurfaceEvent_shell::__shell() const { return *reinterpret_cast<QtJambiShell**>( quintptr(this) + sizeof(QPlatformSurfaceEvent_shell) ); }

jmethodID QPlatformSurfaceEvent_shell::__shell_javaMethod(int pos) const { return QPlatformSurfaceEvent_shell::__shell()->javaMethod(typeid(QPlatformSurfaceEvent), pos); }

// emitting (writeShellConstructor)
QPlatformSurfaceEvent_shell::QPlatformSurfaceEvent_shell(QPlatformSurfaceEvent::SurfaceEventType surfaceEventType0)
    : QPlatformSurfaceEvent(surfaceEventType0)
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("QPlatformSurfaceEvent::QPlatformSurfaceEvent_shell(QPlatformSurfaceEvent::SurfaceEventType surfaceEventType0)", QPlatformSurfaceEvent_shell::__shell())
    QPlatformSurfaceEvent_shell::__shell()->constructed(typeid(QPlatformSurfaceEvent));
}

// emitting (writeShellDestructor)
QPlatformSurfaceEvent_shell::~QPlatformSurfaceEvent_shell()
{
    QTJAMBI_IN_DESTRUCTOR_CALL("QPlatformSurfaceEvent::~QPlatformSurfaceEvent()", QPlatformSurfaceEvent_shell::__shell())
    QPlatformSurfaceEvent_shell::__shell()->destructed(typeid(QPlatformSurfaceEvent));
}

void QPlatformSurfaceEvent_shell::operator delete(void * ptr) noexcept {
    reinterpret_cast<QPlatformSurfaceEvent_shell*>(ptr)->QPlatformSurfaceEvent_shell::__shell()->tryDeleteShell(typeid(QPlatformSurfaceEvent));
}

// emitting Virtual overrides (virtualFunctions)
// emitting Functions in shell class (nonVirtualShellFunctions)
// emitting Public Override Functions (publicOverrideFunctions)
// emitting Virtual Override Functions (virtualOverrideFunctions)
// emitting (writeConstructors)
// new QPlatformSurfaceEvent(QPlatformSurfaceEvent::SurfaceEventType)
void __qt_construct_QPlatformSurfaceEvent_0(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QPlatformSurfaceEvent(QPlatformSurfaceEvent::SurfaceEventType)")
    jobject surfaceEventType0 = __java_arguments[0].l;
    QPlatformSurfaceEvent::SurfaceEventType __qt_surfaceEventType0 = qtjambi_cast<QPlatformSurfaceEvent::SurfaceEventType>(__jni_env, surfaceEventType0);
    QPlatformSurfaceEvent *__qt_this = new(__qtjambi_ptr) QPlatformSurfaceEvent_shell(QPlatformSurfaceEvent::SurfaceEventType(__qt_surfaceEventType0));
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// destruct QPlatformSurfaceEvent_shell
void __qt_destruct_QPlatformSurfaceEvent(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QPlatformSurfaceEvent")
    reinterpret_cast<QPlatformSurfaceEvent_shell*>(ptr)->~QPlatformSurfaceEvent_shell();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QPlatformSurfaceEvent::QPlatformSurfaceEvent(QPlatformSurfaceEvent::SurfaceEventType)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QPlatformSurfaceEvent_initialize_1native__Lio_qt_gui_QPlatformSurfaceEvent_2Lio_qt_gui_QPlatformSurfaceEvent_00024SurfaceEventType_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject surfaceEventType0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QPlatformSurfaceEvent::QPlatformSurfaceEvent(QPlatformSurfaceEvent::SurfaceEventType)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = surfaceEventType0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QPlatformSurfaceEvent_0, sizeof(QPlatformSurfaceEvent_shell), typeid(QPlatformSurfaceEvent), true, &deleter_QPlatformSurfaceEvent, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QPlatformSurfaceEvent::surfaceEventType()const
extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QPlatformSurfaceEvent_surfaceEventType_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jint __java_return_value{0};
    QTJAMBI_TRY {
        const QPlatformSurfaceEvent *__qt_this = QtJambiAPI::objectFromNativeId<QPlatformSurfaceEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QPlatformSurfaceEvent::surfaceEventType()const", __qt_this)
        QPlatformSurfaceEvent::SurfaceEventType __qt_return_value = __qt_this->surfaceEventType();
        __java_return_value = __qt_return_value;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting Field accessors (writeFieldAccessors)
void QPlatformSurfaceEvent_access::setSurfaceEventType_cref_QPlatformSurfaceEvent_SurfaceEventType(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint surfaceEventType0)
{
    Q_UNUSED(__this_nativeId)
    QPlatformSurfaceEvent::SurfaceEventType __qt_surfaceEventType0 = qtjambi_cast<QPlatformSurfaceEvent::SurfaceEventType>(__jni_env, surfaceEventType0);
    this->QPlatformSurfaceEvent::m_surfaceEventType = QPlatformSurfaceEvent::SurfaceEventType(__qt_surfaceEventType0);
}

extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QPlatformSurfaceEvent_setSurfaceEventType_1native_1cref_1QPlatformSurfaceEvent_1SurfaceEventType__JI)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jint surfaceEventType0)
{
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QPlatformSurfaceEvent *__qt_this = QtJambiAPI::objectFromNativeId<QPlatformSurfaceEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        static_cast<QPlatformSurfaceEvent_access*>(__qt_this)->setSurfaceEventType_cref_QPlatformSurfaceEvent_SurfaceEventType(__jni_env, __this_nativeId, surfaceEventType0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
}

// emitting (writeJavaLangObjectOverrideFunctions)
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QPlatformSurfaceEvent_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QPlatformSurfaceEvent *__qt_this = QtJambiAPI::objectFromNativeId<QPlatformSurfaceEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = QtJambiAPI::convertNativeToJavaOwnedObjectAsWrapper(__jni_env, new QPlatformSurfaceEvent(*__qt_this));
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QPlatformSurfaceEvent(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerObjectTypeInfo<QPlatformSurfaceEvent>("QPlatformSurfaceEvent", "io/qt/gui/QPlatformSurfaceEvent");
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QPlatformSurfaceEvent, {
        ConstructorInfo(&__qt_construct_QPlatformSurfaceEvent_0, "Lio/qt/gui/QPlatformSurfaceEvent$SurfaceEventType;")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QPlatformSurfaceEvent);
    registerSizeOfShell(typeId, sizeof(QPlatformSurfaceEvent_shell));
// END: type registration

// BEGIN: polymorphic ids
    registerDefaultPolymorphyHandler<QEvent, QPlatformSurfaceEvent>();
// END: polymorphic ids


// BEGIN: enums and flags
    registerEnumTypeInfo<QPlatformSurfaceEvent::SurfaceEventType>("QPlatformSurfaceEvent::SurfaceEventType", "io/qt/gui/QPlatformSurfaceEvent$SurfaceEventType");
// END: enums and flags
}

==> qtjambi-debuginfo-macos-5.15.19.jar: sources/QtJambiGui/QPlatformSurfaceEvent_shell.cpp <==
#include "QPlatformSurfaceEvent_shell.h"
#include <QtJambi/Cast>

void deleter_QPlatformSurfaceEvent(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QPlatformSurfaceEvent")
    QPlatformSurfaceEvent *_ptr = reinterpret_cast<QPlatformSurfaceEvent *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

QtJambiShell* QPlatformSurfaceEvent_shell::__shell() const { return *reinterpret_cast<QtJambiShell**>( quintptr(this) + sizeof(QPlatformSurfaceEvent_shell) ); }

jmethodID QPlatformSurfaceEvent_shell::__shell_javaMethod(int pos) const { return QPlatformSurfaceEvent_shell::__shell()->javaMethod(typeid(QPlatformSurfaceEvent), pos); }

// emitting (writeShellConstructor)
QPlatformSurfaceEvent_shell::QPlatformSurfaceEvent_shell(const QPlatformSurfaceEvent& other0)
    : QPlatformSurfaceEvent(other0)
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("QPlatformSurfaceEvent::QPlatformSurfaceEvent_shell(const QPlatformSurfaceEvent& other0)", QPlatformSurfaceEvent_shell::__shell())
    QPlatformSurfaceEvent_shell::__shell()->constructed(typeid(QPlatformSurfaceEvent));
}

QPlatformSurfaceEvent_shell::QPlatformSurfaceEvent_shell(QPlatformSurfaceEvent::SurfaceEventType surfaceEventType0)
    : QPlatformSurfaceEvent(surfaceEventType0)
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("QPlatformSurfaceEvent::QPlatformSurfaceEvent_shell(QPlatformSurfaceEvent::SurfaceEventType surfaceEventType0)", QPlatformSurfaceEvent_shell::__shell())
    QPlatformSurfaceEvent_shell::__shell()->constructed(typeid(QPlatformSurfaceEvent));
}

// emitting (writeShellDestructor)
QPlatformSurfaceEvent_shell::~QPlatformSurfaceEvent_shell()
{
    QTJAMBI_IN_DESTRUCTOR_CALL("QPlatformSurfaceEvent::~QPlatformSurfaceEvent()", QPlatformSurfaceEvent_shell::__shell())
    QPlatformSurfaceEvent_shell::__shell()->destructed(typeid(QPlatformSurfaceEvent));
}

void QPlatformSurfaceEvent_shell::operator delete(void * ptr) noexcept {
    reinterpret_cast<QPlatformSurfaceEvent_shell*>(ptr)->QPlatformSurfaceEvent_shell::__shell()->tryDeleteShell(typeid(QPlatformSurfaceEvent));
}

// emitting Virtual overrides (virtualFunctions)
// emitting Functions in shell class (nonVirtualShellFunctions)
// emitting Public Override Functions (publicOverrideFunctions)
// emitting Virtual Override Functions (virtualOverrideFunctions)
// emitting (writeConstructors)
// new QPlatformSurfaceEvent(QPlatformSurfaceEvent)
void __qt_construct_QPlatformSurfaceEvent_cref_QPlatformSurfaceEvent(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QPlatformSurfaceEvent(QPlatformSurfaceEvent)")
    jobject other0 = __java_arguments[0].l;
    const QPlatformSurfaceEvent& __qt_other0 = qtjambi_cast<const QPlatformSurfaceEvent& >(__jni_env, other0);
    QPlatformSurfaceEvent *__qt_this = new(__qtjambi_ptr) QPlatformSurfaceEvent_shell(__qt_other0);
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// QPlatformSurfaceEvent::QPlatformSurfaceEvent(QPlatformSurfaceEvent)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QPlatformSurfaceEvent_initialize_1native__Lio_qt_gui_QPlatformSurfaceEvent_2Lio_qt_gui_QPlatformSurfaceEvent_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject other0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QPlatformSurfaceEvent::QPlatformSurfaceEvent(QPlatformSurfaceEvent)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = other0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QPlatformSurfaceEvent_cref_QPlatformSurfaceEvent, sizeof(QPlatformSurfaceEvent_shell), typeid(QPlatformSurfaceEvent), true, &deleter_QPlatformSurfaceEvent, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// new QPlatformSurfaceEvent(QPlatformSurfaceEvent::SurfaceEventType)
void __qt_construct_QPlatformSurfaceEvent_QPlatformSurfaceEvent_SurfaceEventType(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QPlatformSurfaceEvent(QPlatformSurfaceEvent::SurfaceEventType)")
    jobject surfaceEventType0 = __java_arguments[0].l;
    QPlatformSurfaceEvent::SurfaceEventType __qt_surfaceEventType0 = qtjambi_cast<QPlatformSurfaceEvent::SurfaceEventType>(__jni_env, surfaceEventType0);
    QPlatformSurfaceEvent *__qt_this = new(__qtjambi_ptr) QPlatformSurfaceEvent_shell(QPlatformSurfaceEvent::SurfaceEventType(__qt_surfaceEventType0));
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// QPlatformSurfaceEvent::QPlatformSurfaceEvent(QPlatformSurfaceEvent::SurfaceEventType)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QPlatformSurfaceEvent_initialize_1native__Lio_qt_gui_QPlatformSurfaceEvent_2Lio_qt_gui_QPlatformSurfaceEvent_00024SurfaceEventType_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject surfaceEventType0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QPlatformSurfaceEvent::QPlatformSurfaceEvent(QPlatformSurfaceEvent::SurfaceEventType)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = surfaceEventType0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QPlatformSurfaceEvent_QPlatformSurfaceEvent_SurfaceEventType, sizeof(QPlatformSurfaceEvent_shell), typeid(QPlatformSurfaceEvent), true, &deleter_QPlatformSurfaceEvent, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// destruct QPlatformSurfaceEvent_shell
void __qt_destruct_QPlatformSurfaceEvent(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QPlatformSurfaceEvent")
    reinterpret_cast<QPlatformSurfaceEvent_shell*>(ptr)->~QPlatformSurfaceEvent_shell();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QPlatformSurfaceEvent::surfaceEventType()const
extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QPlatformSurfaceEvent_surfaceEventType_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jint __java_return_value{0};
    QTJAMBI_TRY {
        const QPlatformSurfaceEvent *__qt_this = QtJambiAPI::objectFromNativeId<QPlatformSurfaceEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QPlatformSurfaceEvent::surfaceEventType()const", __qt_this)
        QPlatformSurfaceEvent::SurfaceEventType __qt_return_value = __qt_this->surfaceEventType();
        __java_return_value = __qt_return_value;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting Field accessors (writeFieldAccessors)
void QPlatformSurfaceEvent_access::setSurfaceEventType_cref_QPlatformSurfaceEvent_SurfaceEventType(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint surfaceEventType0)
{
    Q_UNUSED(__this_nativeId)
    QPlatformSurfaceEvent::SurfaceEventType __qt_surfaceEventType0 = qtjambi_cast<QPlatformSurfaceEvent::SurfaceEventType>(__jni_env, surfaceEventType0);
    this->QPlatformSurfaceEvent::m_surfaceEventType = QPlatformSurfaceEvent::SurfaceEventType(__qt_surfaceEventType0);
}

extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QPlatformSurfaceEvent_setSurfaceEventType_1native_1cref_1QPlatformSurfaceEvent_1SurfaceEventType__JI)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jint surfaceEventType0)
{
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QPlatformSurfaceEvent *__qt_this = QtJambiAPI::objectFromNativeId<QPlatformSurfaceEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        static_cast<QPlatformSurfaceEvent_access*>(__qt_this)->setSurfaceEventType_cref_QPlatformSurfaceEvent_SurfaceEventType(__jni_env, __this_nativeId, surfaceEventType0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
}

// emitting (writeJavaLangObjectOverrideFunctions)
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QPlatformSurfaceEvent_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QPlatformSurfaceEvent *__qt_this = QtJambiAPI::objectFromNativeId<QPlatformSurfaceEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = QtJambiAPI::convertNativeToJavaOwnedObjectAsWrapper(__jni_env, new QPlatformSurfaceEvent(*__qt_this));
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QPlatformSurfaceEvent(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerObjectTypeInfo<QPlatformSurfaceEvent>("QPlatformSurfaceEvent", "io/qt/gui/QPlatformSurfaceEvent");
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QPlatformSurfaceEvent, {
        ConstructorInfo(&__qt_construct_QPlatformSurfaceEvent_cref_QPlatformSurfaceEvent, "Lio/qt/gui/QPlatformSurfaceEvent;")
       ,ConstructorInfo(&__qt_construct_QPlatformSurfaceEvent_QPlatformSurfaceEvent_SurfaceEventType, "Lio/qt/gui/QPlatformSurfaceEvent$SurfaceEventType;")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QPlatformSurfaceEvent);
    registerSizeOfShell(typeId, sizeof(QPlatformSurfaceEvent_shell));
// END: type registration

// BEGIN: polymorphic ids
    registerDefaultPolymorphyHandler<QEvent, QPlatformSurfaceEvent>();
// END: polymorphic ids


// BEGIN: enums and flags
    registerEnumTypeInfo<QPlatformSurfaceEvent::SurfaceEventType>("QPlatformSurfaceEvent::SurfaceEventType", "io/qt/gui/QPlatformSurfaceEvent$SurfaceEventType");
// END: enums and flags
}
